@@ -172,6 +172,29 @@ private extension AudioMiniPlayer {
                                                                              constant: -8),
                                      ])
     }
+
+    private func applyCustomEqualizerProfileIfNeeded() {
+        let userDefaults = UserDefaults.standard
+        guard userDefaults.bool(forKey: kVLCCustomProfileEnabled) else {
+            return
+        }
+
+        let profileIndex = userDefaults.integer(forKey: kVLCSettingEqualizerProfile)
+        let encodedData = userDefaults.data(forKey: kVLCCustomEqualizerProfiles)
+
+        guard let encodedData = encodedData,
+              let customProfiles = NSKeyedUnarchiver(forReadingWith: encodedData).decodeObject(forKey: "root") as? CustomEqualizerProfiles,
+              profileIndex < customProfiles.profiles.count else {
+            return
+        }
+
+        let selectedProfile = customProfiles.profiles[profileIndex]
+        playbackService.preAmplification = CGFloat(selectedProfile.preAmpLevel)
+
+        for (index, frequency) in selectedProfile.frequencies.enumerated() {
+            playbackService.setAmplification(CGFloat(frequency), forBand: UInt32(index))
+        }
+    }
 }
 
 // MARK: - VLCPlaybackServiceDelegate
@@ -200,6 +223,10 @@ extension AudioMiniPlayer: VLCPlaybackServiceDelegate {
         if let queueCollectionView = queueViewController?.queueCollectionView {
             queueCollectionView.reloadData()
         }
+
+        if currentState == .opening {
+            applyCustomEqualizerProfileIfNeeded()
+        }
     }
 
     func displayMetadata(for playbackService: PlaybackService, metadata: VLCMetaData) {
